@@ -6,7 +6,7 @@ from .batch import (
     CVMTest,
     EMD,
     HellingerDistance,
-    HistogramIntersection,
+    HINormalizedComplement,
     JS,
     KL,
     KSTest,
@@ -23,7 +23,7 @@ __all__ = [
     "CVMTest",
     "EMD",
     "HellingerDistance",
-    "HistogramIntersection",
+    "HINormalizedComplement",
     "IncrementalKSTest",
     "JS",
     "KL",
