@@ -4,7 +4,7 @@ from .distance_based import (
     BhattacharyyaDistance,
     EMD,
     HellingerDistance,
-    HistogramIntersection,
+    HINormalizedComplement,
     JS,
     KL,
     PSI,
@@ -23,7 +23,7 @@ __all__ = [
     "CVMTest",
     "EMD",
     "HellingerDistance",
-    "HistogramIntersection",
+    "HINormalizedComplement",
     "JS",
     "KL",
     "KSTest",
